<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>HomeDaemon</name>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="55"/>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="57"/>
        <source>Show main window</source>
        <translation>メインウィンドウを表示</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="72"/>
        <source>Communication</source>
        <translation>コミュニケーション</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="75"/>
        <source>Exit</source>
        <translation>終了</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="315"/>
        <source>View</source>
        <translation>表示</translation>
    </message>
</context>
</TS>